diff --git a/src/js/client.js b/src/js/client.js
index 8940e42eb..75cf86fe0 100644
--- a/src/js/client.js
+++ b/src/js/client.js
@@ -193,7 +193,7 @@ const REGIONS_VULTR = [
{ name: 'Singapore', value: 'https://sgp1.vultrobjects.com', region: 'ap-southeast-1' },
];
-const STORAGE_PROVIDER = [
+const STORAGE_PROVIDERS = [
{ name: 'Amazon S3', value: 's3' },
{ name: 'Backblaze B2 (S3 API)', value: 'backblaze-b2' },
{ name: 'CIFS Mount', value: 'cifs' },
diff --git a/src/restore.html b/src/restore.html
index 59d644500..fb1c53b7d 100644
--- a/src/restore.html
+++ b/src/restore.html
@@ -90,7 +90,7 @@
diff --git a/src/views/app.html b/src/views/app.html
index 9c779df44..635d3ca70 100644
--- a/src/views/app.html
+++ b/src/views/app.html
@@ -238,7 +238,7 @@
diff --git a/src/views/app.js b/src/views/app.js
index 3c9065719..8a619ecea 100644
--- a/src/views/app.js
+++ b/src/views/app.js
@@ -9,7 +9,7 @@
/* global Chart */
/* global Clipboard */
/* global SECRET_PLACEHOLDER */
-/* global APP_TYPES, STORAGE_PROVIDER, BACKUP_FORMATS */
+/* global APP_TYPES, STORAGE_PROVIDERS, BACKUP_FORMATS */
/* global REGIONS_S3, REGIONS_WASABI, REGIONS_DIGITALOCEAN, REGIONS_EXOSCALE, REGIONS_SCALEWAY, REGIONS_LINODE, REGIONS_OVH, REGIONS_IONOS, REGIONS_UPCLOUD, REGIONS_VULTR */
angular.module('Application').controller('AppController', ['$scope', '$location', '$translate', '$timeout', '$interval', '$route', '$routeParams', 'Client', function ($scope, $location, $translate, $timeout, $interval, $route, $routeParams, Client) {
@@ -24,7 +24,7 @@ angular.module('Application').controller('AppController', ['$scope', '$location'
$scope.upcloudRegions = REGIONS_UPCLOUD;
$scope.vultrRegions = REGIONS_VULTR;
- $scope.storageProvider = STORAGE_PROVIDER;
+ $scope.storageProviders = STORAGE_PROVIDERS;
$scope.formats = BACKUP_FORMATS;
diff --git a/src/views/backups.html b/src/views/backups.html
index ae64a2ff9..e6d9901f4 100644
--- a/src/views/backups.html
+++ b/src/views/backups.html
@@ -161,7 +161,7 @@
diff --git a/src/views/backups.js b/src/views/backups.js
index 366b86ac7..c3bab7af7 100644
--- a/src/views/backups.js
+++ b/src/views/backups.js
@@ -29,7 +29,7 @@ angular.module('Application').controller('BackupsController', ['$scope', '$locat
$scope.upcloudRegions = REGIONS_UPCLOUD;
$scope.vultrRegions = REGIONS_VULTR;
- $scope.storageProvider = STORAGE_PROVIDER.concat([
+ $scope.storageProviders = STORAGE_PROVIDERS.concat([
{ name: 'No-op (Only for testing)', value: 'noop' }
]);
diff --git a/src/js/restore.js b/src/js/restore.js
index d51d0d754..c2d1dd32e 100644
--- a/src/js/restore.js
+++ b/src/js/restore.js
@@ -1,6 +1,6 @@
'use strict';
/* global $, angular, tld, SECRET_PLACEHOLDER, STORAGE_PROVIDER, BACKUP_FORMATS */
/* global REGIONS_S3, REGIONS_WASABI, REGIONS_DIGITALOCEAN, REGIONS_EXOSCALE, REGIONS_SCALEWAY, REGIONS_LINODE, REGIONS_OVH, REGIONS_IONOS, REGIONS_UPCLOUD, REGIONS_VULTR */
// create main application module
@@ -86,7 +86,7 @@ app.controller('RestoreController', ['$scope', 'Client', function ($scope, Clien
$scope.upcloudRegions = REGIONS_UPCLOUD;
$scope.vultrRegions = REGIONS_VULTR;
- $scope.storageProvider = STORAGE_PROVIDER;
+ $scope.storageProviders = STORAGE_PROVIDERS;
$scope.formats = BACKUP_FORMATS;
@@ -1,6 +1,6 @@
'use strict';
-/* global $, angular, tld, SECRET_PLACEHOLDER, STORAGE_PROVIDER, BACKUP_FORMATS */
+/* global $, angular, tld, SECRET_PLACEHOLDER, STORAGE_PROVIDERS, BACKUP_FORMATS */
/* global REGIONS_S3, REGIONS_WASABI, REGIONS_DIGITALOCEAN, REGIONS_EXOSCALE, REGIONS_SCALEWAY, REGIONS_LINODE, REGIONS_OVH, REGIONS_IONOS, REGIONS_UPCLOUD, REGIONS_VULTR */
// create main application module